'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var React = require('react');
var classnames = require('classnames');
var index = require('../icon/index.js');
var index$1 = require('../loading/index.js');
var index$3 = require('../popup/index.js');
var props = require('../popup/props.js');
var index$2 = require('../utils/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-action-sheet';

const ActionSheet = props$1 => {
  const {
    show = false,
    actions,
    title,
    cancelText,
    description,
    closeOnClickAction = true,
    round = true,
    closeable = true,
    closeIcon = 'cross',
    safeAreaInsetBottom,
    onSelect,
    onCancel,
    onOpen,
    onOpened,
    onClose,
    onClosed,
    onClickOverlay,
    children
  } = props$1;
  const [visible, setVisible] = React.useState(false);
  React.useEffect(() => {
    setVisible(show);
  }, [show]); // const popupDefaultPropKeys = Object.keys(defultProps);

  const popupDefaultPropKeys = Object.keys(props.defultPopupSharedProps);
  const handleCancel = React.useCallback(() => {
    setVisible(false);
    onCancel == null ? void 0 : onCancel();
  }, [onCancel]);
  const renderHeader = React.useMemo(() => {
    if (title) {
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](`${baseClass}__header`)
      }, title, closeable && /*#__PURE__*/React__default['default'].createElement(index['default'], {
        name: closeIcon,
        className: classnames__default['default'](`${baseClass}__close`),
        onClick: handleCancel
      }));
    }

    return null;
  }, [title, closeable, closeIcon, handleCancel]);
  const renderCancelBtn = React.useMemo(() => {
    if (cancelText) {
      return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](`${baseClass}__gap`)
      }), /*#__PURE__*/React__default['default'].createElement("button", {
        type: "button",
        className: classnames__default['default'](`${baseClass}__cancel`),
        onClick: handleCancel
      }, cancelText));
    }

    return null;
  }, [cancelText, handleCancel]);
  const renderOption = React.useCallback((item, index) => {
    const {
      name,
      color,
      subname,
      loading,
      callback,
      disabled,
      className
    } = item;
    const Content = loading ? /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
      className: classnames__default['default'](`${baseClass}__loading-icon`)
    }) : /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, /*#__PURE__*/React__default['default'].createElement("span", {
      className: classnames__default['default'](`${baseClass}__name`)
    }, name), subname && /*#__PURE__*/React__default['default'].createElement("div", {
      className: classnames__default['default'](`${baseClass}__subname`)
    }, subname)); // 点击选项

    const onClickItem = () => {
      if (disabled || loading) {
        return;
      }

      callback == null ? void 0 : callback(item); // 点击选项后触发

      onSelect == null ? void 0 : onSelect(item, index); // 在点击选项后关闭

      if (closeOnClickAction) {
        // 设置actionsheet的show的状态
        setVisible(false);
      }
    };

    return /*#__PURE__*/React__default['default'].createElement("button", {
      type: "button",
      style: {
        color
      },
      className: classnames__default['default'](`${baseClass}__item`, {
        [`${baseClass}__item--loading`]: loading,
        [`${baseClass}__item--disabled`]: disabled
      }, className),
      onClick: onClickItem,
      key: name
    }, Content);
  }, [onSelect, closeOnClickAction]);
  const renderOptions = React.useMemo(() => {
    if (actions) {
      return actions.map(renderOption);
    }

    return null;
  }, [actions, renderOption]);
  const renderDescription = React.useMemo(() => {
    return index$2.isDef(description) && description !== '' ? /*#__PURE__*/React__default['default'].createElement("div", {
      className: classnames__default['default'](`${baseClass}__description`)
    }, description) : /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null);
  }, [description]);
  return /*#__PURE__*/React__default['default'].createElement(index$3['default'], _extends__default['default']({
    className: classnames__default['default'](`${baseClass}`)
  }, index$2.pick(props$1, popupDefaultPropKeys), {
    show: visible,
    round: round,
    position: "bottom",
    safeAreaInsetBottom: safeAreaInsetBottom,
    onClickOverlay: onClickOverlay,
    onOpen: onOpen,
    onOpened: onOpened,
    onClose: onClose,
    onClosed: onClosed
  }), renderHeader, renderDescription, /*#__PURE__*/React__default['default'].createElement("div", {
    className: classnames__default['default'](`${baseClass}__content`)
  }, renderOptions, children), renderCancelBtn);
};

exports.default = ActionSheet;
