'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index = require('../utils/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-badge';

const Badge = props => {
  const {
    dot,
    max,
    content,
    color,
    tag = 'div',
    className,
    offset,
    style,
    children,
    onClick
  } = props;
  const Tag = tag;
  const isIcon = React.useRef(false);

  const hasContent = () => {
    if (isIcon.current) {
      return true;
    }

    return index.isDef(content) && content !== '';
  };

  const renderContent = () => {
    if (!dot && hasContent()) {
      if (isIcon.current) {
        return React__default['default'].Children.map(children, child => {
          var _child$type;

          if ((child == null ? void 0 : (_child$type = child.type) == null ? void 0 : _child$type.name) === 'Icon') {
            return child;
          }

          return null;
        });
      }
    }

    if (index.isDef(max) && index.isDef(content) && Number(content) > Number(max)) {
      const maxNum = Number(max);
      return `${maxNum}+`;
    }

    return content;
  };

  const renderBadge = () => {
    if (hasContent() || dot) {
      const styleProperties = {
        background: color
      };

      if (offset) {
        const [x, y] = offset;

        if (content) {
          styleProperties.top = `${y}px`;
          styleProperties.right = `${-x}px`;
        } else {
          styleProperties.marginTop = `${y}px`;
          styleProperties.marginLeft = `${x}px`;
        }
      }

      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](baseClass, {
          [`${baseClass}--fixed`]: !!children,
          [`${baseClass}--dot`]: dot
        }),
        style: styleProperties
      }, renderContent());
    }

    return null;
  };

  const withoutChildren = () => {
    return renderBadge();
  };

  const handleClick = e => {
    onClick == null ? void 0 : onClick(e);
  };

  const hasChildren = () => {
    return /*#__PURE__*/React__default['default'].createElement(Tag, {
      className: classnames__default['default'](`${baseClass}__wrapper`, className),
      onClick: handleClick,
      style: style
    }, React__default['default'].Children.map(children, child => {
      var _child$type2;

      if ((child == null ? void 0 : (_child$type2 = child.type) == null ? void 0 : _child$type2.name) === 'Icon') {
        isIcon.current = true;
      }

      return child;
    }), renderBadge());
  };

  return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, children ? hasChildren() : withoutChildren());
};

exports.default = Badge;
