'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index = require('../loading/index.js');
var index$1 = require('../icon/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-button';

const Button = props => {
  const {
    type = 'default',
    plain = false,
    disabled = false,
    loading = false,
    round = false,
    square = false,
    block = false,
    hairline = false,
    size = 'normal',
    loadingType = 'circular',
    loadingText,
    loadingSize = '16px',
    text,
    color,
    className,
    tag = 'button',
    nativeType,
    onClick,
    icon,
    iconPrefix = 'r-icon',
    iconPosition = 'left',
    children
  } = props;
  const Tag = tag || 'button';
  const Cls = classnames__default['default']( // `${baseClass}`],
  baseClass, {
    [`${baseClass}--${type}`]: !!type,
    [`${baseClass}--${size}`]: !!size,
    [`${baseClass}--plain`]: plain,
    [`${baseClass}--disabled`]: disabled,
    [`${baseClass}--loading`]: loading,
    [`${baseClass}--round`]: round,
    [`${baseClass}--square`]: square,
    [`${baseClass}--block`]: block,
    [`${baseClass}--hairline`]: hairline,
    [`${baseClass}__${icon}`]: !!icon
  }, className);
  const renderIcon = React.useMemo(() => {
    if (loading) {
      return /*#__PURE__*/React__default['default'].createElement(index['default'], {
        color: color,
        size: loadingSize,
        type: loadingType
      });
    }

    if (icon) {
      return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
        className: classnames__default['default'](`${baseClass}__icon`),
        classPrefix: iconPrefix,
        color: color,
        name: icon
      });
    }

    return null;
  }, [loading, icon, loadingType, loadingSize, color, iconPrefix]);
  const renderContent = React.useMemo(() => {
    let content;

    if (loading) {
      content = loadingText;
    } else {
      content = children || text;
    }

    if (content) {
      return /*#__PURE__*/React__default['default'].createElement("span", {
        className: classnames__default['default'](`${baseClass}__text`)
      }, content);
    }

    return null;
  }, [loading, loadingText, text, children]);
  const getStyle = React.useCallback(() => {
    if (color) {
      const style = {};
      style.color = plain ? color : 'white';

      if (!plain) {
        // 为了使linear-gradient起作用，请用background 代替 backgroundColor
        style.background = color;
        style.border = 'none';
      } // 当是渐变色是，去掉边框。


      if (color.indexOf('gradient') !== -1) {
        style.border = 'none';
      } else {
        style.borderColor = color;
      }

      return style;
    }

    return null;
  }, [color, plain]);

  const handleClick = e => {
    if (!disabled || !loading) {
      onClick == null ? void 0 : onClick(e);
    }
  };

  return /*#__PURE__*/React__default['default'].createElement(Tag, {
    className: Cls,
    disabled: disabled,
    onClick: handleClick,
    style: getStyle(),
    type: nativeType
  }, /*#__PURE__*/React__default['default'].createElement("div", {
    className: classnames__default['default'](`${baseClass}__content`)
  }, iconPosition === 'left' && renderIcon, renderContent, iconPosition === 'right' && renderIcon));
};

exports.default = Button;
