'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index = require('../utils/index.js');
var index$1 = require('../icon/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-cell';
const Cell = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    icon,
    size,
    title,
    value,
    label,
    center = false,
    isLink = false,
    required = false,
    iconPrefix = 'r-icon',
    valueClass,
    labelClass,
    titleClass,
    titleStyle,
    arrowDirection = 'right',
    border = true,
    clickable = true,
    className,
    onClick,
    children
  } = props;
  const isClickable = clickable != null ? clickable : isLink;
  const renderLabel = React.useMemo(() => {
    const showLabel = index.isDef(label);

    if (showLabel) {
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](`${baseClass}__label`, labelClass)
      }, label);
    }

    return null;
  }, [label, labelClass]);
  const renderTitle = React.useMemo(() => {
    if (index.isDef(title)) {
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](`${baseClass}__title`, titleClass),
        style: titleStyle
      }, /*#__PURE__*/React__default['default'].createElement("span", null, title), renderLabel);
    }

    return null;
  }, [title, titleStyle, titleClass, renderLabel]);
  const renderValue = React.useMemo(() => {
    const hasValue = children || index.isDef(value);

    if (hasValue) {
      const hasTitle = index.isDef(title);
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classnames__default['default'](`${baseClass}__value`, {
          [`${baseClass}__value--alone`]: !hasTitle
        }, valueClass)
      }, children || /*#__PURE__*/React__default['default'].createElement("span", null, value));
    }

    return null;
  }, [valueClass, title, value, children]);
  const renderLeftIcon = React.useMemo(() => {
    if (icon) {
      return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
        name: icon,
        className: classnames__default['default'](`${baseClass}__left-icon`),
        classPrefix: iconPrefix
      });
    }

    return null;
  }, [icon, iconPrefix]);
  const renderRightIcon = React.useMemo(() => {
    if (isLink) {
      const name = arrowDirection ? `arrow-${arrowDirection}` : 'arrow';
      return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
        name: name,
        className: classnames__default['default'](`${baseClass}__right-icon`)
      });
    }

    return null;
  }, [isLink, arrowDirection]);

  const handleClick = e => {
    onClick == null ? void 0 : onClick(e);
  };

  return /*#__PURE__*/React__default['default'].createElement("div", {
    ref: ref,
    className: classnames__default['default'](baseClass, {
      [`${baseClass}--large`]: !!size,
      [`${baseClass}--center`]: center,
      [`${baseClass}--required`]: required,
      [`${baseClass}--clickable`]: isClickable,
      [`${baseClass}--borderless`]: !border
    }, className),
    role: clickable ? 'button' : undefined // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
    ,
    tabIndex: clickable ? 0 : undefined,
    onClick: handleClick
  }, renderLeftIcon, renderTitle, renderValue, renderRightIcon);
});
Cell.displayName = 'Cell';

exports.default = Cell;
