'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index = require('../utils/index.js');
var index$1 = require('../icon/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const Checker = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    shape = 'round',
    imgUrl,
    disabled = false,
    labelDisabled = false,
    labelPosition = 'right',
    iconSize = '16px',
    bindGroup = true,
    checked,
    checkedColor = '#1989fa',
    parent,
    role,
    onClick,
    onToggle,
    children,
    baseClass
  } = props;
  const iconRef = React.useRef(null);
  const getParentProp = React.useCallback(arg => {
    if (parent && bindGroup) {
      return parent[arg];
    }

    return null;
  }, [parent, bindGroup]); // 父组件传递的排列方向

  const directionVal = () => {
    return getParentProp('direction') || null;
  }; // 是否禁用


  const disabledStatus = React.useMemo(() => {
    return getParentProp('disabled') || disabled;
  }, [getParentProp, disabled]); // icon行内样式

  const iconStyle = React.useCallback(() => {
    const checkedStatusColor = getParentProp('checkedColor') || checkedColor;

    if (checked && checkedStatusColor && !disabledStatus) {
      return {
        borderColor: checkedStatusColor,
        backgroundColor: checkedStatusColor
      };
    }

    return null;
  }, [checkedColor, checked, disabledStatus, getParentProp]); // 外层样式

  const iconWrapperClassString = classnames__default['default'](`${baseClass}__icon`, {
    [`${baseClass}__icon--round`]: shape === 'round',
    [`${baseClass}__icon--disabled`]: disabledStatus,
    [`${baseClass}__icon--checked`]: checked,
    [`${baseClass}__icon--double`]: disabledStatus && checked
  });
  const classString = classnames__default['default'](baseClass, `${baseClass}--${directionVal()}`, {
    [`${baseClass}--label-disabled`]: labelDisabled,
    [`${baseClass}--disabled`]: disabledStatus
  });
  const renderIcon = React.useMemo(() => {
    return /*#__PURE__*/React__default['default'].createElement("div", {
      ref: iconRef,
      className: iconWrapperClassString,
      style: {
        fontSize: index.addUnit((parent == null ? void 0 : parent.iconSize) || iconSize)
      }
    }, imgUrl ? /*#__PURE__*/React__default['default'].createElement("img", {
      alt: "pic",
      src: checked ? imgUrl.activeIcon : imgUrl.inactiveIcon,
      className: classnames__default['default'](`${baseClass}__imgUrl`)
    }) : /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
      name: "success",
      className: classnames__default['default']('r-icon'),
      style: iconStyle()
    }));
  }, [iconSize, parent == null ? void 0 : parent.iconSize, checked, iconWrapperClassString, imgUrl, baseClass, iconStyle]);
  const renderLabel = React.useMemo(() => {
    const classString = classnames__default['default'](`${baseClass}__label`, `${baseClass}__label--${labelPosition}`, {
      [`${baseClass}__label--disabled`]: disabledStatus
    });
    return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, children && /*#__PURE__*/React__default['default'].createElement("span", {
      className: classString
    }, children));
  }, [labelPosition, disabledStatus, children, baseClass]);
  const nodes = [renderIcon];

  if (labelPosition === 'left') {
    nodes.unshift(renderLabel);
  } else {
    nodes.push(renderLabel);
  } // 点击checkbox


  const handleClick = e => {
    const {
      target
    } = e;
    const icon = iconRef.current; // 当点击的是复选框 或者 点击的区域包括复选框

    const iconClicked = icon === target || (icon == null ? void 0 : icon.contains(target)); // 复选框没被禁用，并且（复选框被点击或者文本内容没被禁用的情况下）

    if (!disabledStatus && (iconClicked || !labelDisabled)) {
      // 状态取反
      onToggle == null ? void 0 : onToggle(!checked);
    } // 触发onClick事件


    onClick == null ? void 0 : onClick(e);
  };

  React.useImperativeHandle(ref, () => ({
    handleClick
  }));
  return /*#__PURE__*/React__default['default'].createElement("div", {
    ref: ref,
    onClick: handleClick,
    className: classString,
    role: role,
    tabIndex: disabledStatus ? -1 : 0,
    "aria-checked": checked
  }, nodes.map(item => {
    return /*#__PURE__*/React__default['default'].cloneElement(item, {
      key: item == null ? void 0 : item.toString()
    });
  }));
});
Checker.displayName = 'Checker';

exports.default = Checker;
