'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var React = require('react');
var index = require('../checkbox-group/index.js');
var checker = require('./checker.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);

const Checkbox = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    name,
    model = false,
    bindGroup = true,
    onChange
  } = props; // 获取共享上下文

  const parent = React.useContext(index.CheckboxGroupContext); // 初始化状态

  const [modelValue, setModelValue] = React.useState(model);
  React.useEffect(() => {
    onChange == null ? void 0 : onChange(modelValue);
  }, [modelValue, onChange]); // 更新父组件的model值(当有父组件时)

  const updateParentModel = checked => {
    const {
      model,
      max,
      onChange
    } = parent;

    if (checked) {
      // 判断父组件的model值的数量是否大于设置的max值
      const overLimit = max && (model == null ? void 0 : model.length) >= max;

      if (!overLimit && (model == null ? void 0 : model.indexOf(name)) === -1) {
        setModelValue(checked);
        model.push(name);

        if (bindGroup) {
          onChange == null ? void 0 : onChange(model);
        }
      }
    } else {
      const index = model.indexOf(name);

      if (index !== -1) {
        setModelValue(checked);
        model.splice(index, 1);

        if (bindGroup) {
          onChange == null ? void 0 : onChange(model);
        }
      }
    }
  };

  const toggle = (newVal = !modelValue) => {
    if (parent && bindGroup) {
      updateParentModel(newVal);
    } else {
      setModelValue(newVal);
    }
  };

  React.useImperativeHandle(ref, () => ({
    toggle
  }));
  return /*#__PURE__*/React__default['default'].createElement(checker['default'], _extends__default['default']({
    ref: ref,
    baseClass: "r-checkbox",
    role: "checkbox",
    parent: parent,
    checked: modelValue,
    onToggle: toggle
  }, props));
});
Checkbox.displayName = 'Checkbox';

exports.default = Checkbox;
