'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index$3 = require('../utils/index.js');
var index$2 = require('../popup/index.js');
var index = require('../button/index.js');
var index$1 = require('../action-bar/index.js');
var callIntercepter = require('../utils/callIntercepter.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-dialog';

const Dialog = props => {
  const {
    show = false,
    title,
    theme = 'default',
    width = '320px',
    message = '',
    className,
    onBeforeClose,
    messageAlign = 'center',
    showCancelButton = false,
    cancelButtonText = '取消',
    cancelButtonColor = '#000000',
    confirmButtonText = '确认',
    confirmButtonColor = '#ee0a24',
    showConfirmButton = true,
    onClickOverlay,
    onConfirm,
    onCancel,
    onOpen,
    onOpened,
    onClose,
    onClosed,
    updateShow
  } = props;
  const [visible, setVisible] = React.useState(false);
  const [loadingConfirm, setLoadingConfirm] = React.useState(false);
  const [loadingCancel, setLoadingCancel] = React.useState(false);
  React.useEffect(() => {
    setVisible(show);
  }, [show]);

  const handleLoadingStatus = (action, status) => {
    // eslint-disable-next-line no-param-reassign
    // action === 'confirm' ? setLoadingConfirm(status) : setLoadingCancel(status);
    if (action === 'confirm') {
      setLoadingConfirm(status);
    } else {
      setLoadingCancel(status);
    }
  }; // 处理按钮的点击事件


  const handleAction = React.useCallback(action => {
    if (!show) {
      return;
    }

    if (action === 'confirm') {
      onConfirm == null ? void 0 : onConfirm();
    } else {
      onCancel == null ? void 0 : onCancel();
    }

    if (onBeforeClose) {
      handleLoadingStatus(action, true);
      callIntercepter.callIntercepter({
        interceptor: onBeforeClose,
        args: [action],
        done: () => {
          handleLoadingStatus(action, false);
          updateShow == null ? void 0 : updateShow(false);
        },
        canceled: () => {
          handleLoadingStatus(action, false);
          updateShow == null ? void 0 : updateShow(false);
        }
      });
    } else {
      updateShow == null ? void 0 : updateShow(false);
    }
  }, [show, onBeforeClose, onConfirm, onCancel, updateShow]);
  const renderTitle = React.useMemo(() => {
    const titleCls = classnames__default['default'](`${baseClass}__header`, {
      [`${baseClass}__header--isolated`]: !message
    });

    if (title) {
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: titleCls
      }, title);
    }

    return null;
  }, [title, message]);
  const renderContent = React.useMemo(() => {
    const classStringWrapper = classnames__default['default'](`${baseClass}__content`, {
      [`${baseClass}__content--isolated`]: !title
    });
    const classStringInner = classnames__default['default'](`${baseClass}__message`, {
      [`${baseClass}__message--has-title`]: title,
      [`${baseClass}__message--${messageAlign}`]: messageAlign
    });

    if (message) {
      return /*#__PURE__*/React__default['default'].createElement("div", {
        className: classStringWrapper
      }, /*#__PURE__*/React__default['default'].createElement("div", {
        className: classStringInner
      }, message));
    }

    return null;
  }, [message, title, messageAlign]);
  const renderButtons = React.useMemo(() => {
    return /*#__PURE__*/React__default['default'].createElement("div", {
      className: classnames__default['default'](`${baseClass}__footer`, `${baseClass}__border--top`)
    }, showCancelButton && /*#__PURE__*/React__default['default'].createElement(index['default'], {
      size: "large",
      text: cancelButtonText,
      className: classnames__default['default'](`${baseClass}__cancel`),
      style: {
        color: cancelButtonColor
      },
      loading: loadingCancel,
      onClick: () => handleAction('cancel')
    }), showConfirmButton && /*#__PURE__*/React__default['default'].createElement(index['default'], {
      size: "large",
      text: confirmButtonText,
      className: classnames__default['default'](`${baseClass}__confirm`, {
        [`${baseClass}__border--left`]: showCancelButton
      }),
      style: {
        color: confirmButtonColor
      },
      loading: loadingConfirm,
      onClick: () => handleAction('confirm')
    }));
  }, [showCancelButton, loadingCancel, cancelButtonText, cancelButtonColor, showConfirmButton, loadingConfirm, confirmButtonText, confirmButtonColor, handleAction]);
  const renderRoundButtons = React.useMemo(() => {
    return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
      className: classnames__default['default'](`${baseClass}__footer`)
    }, showCancelButton && /*#__PURE__*/React__default['default'].createElement(index['default'], {
      size: "large",
      type: "warning",
      text: cancelButtonText,
      className: classnames__default['default'](`${baseClass}__cancel`, `${baseClass}__cancel__space-around`),
      round: true,
      color: cancelButtonColor,
      loading: loadingCancel,
      onClick: () => handleAction('cancel')
    }), showConfirmButton && /*#__PURE__*/React__default['default'].createElement(index['default'], {
      size: "large",
      type: "danger",
      text: confirmButtonText,
      round: true,
      className: classnames__default['default'](`${baseClass}__confirm`, `${baseClass}__confirm__space-around`),
      color: confirmButtonColor,
      loading: loadingConfirm,
      onClick: () => handleAction('confirm')
    }));
  }, [showCancelButton, loadingCancel, cancelButtonText, cancelButtonColor, showConfirmButton, loadingConfirm, confirmButtonText, confirmButtonColor, handleAction]);
  return /*#__PURE__*/React__default['default'].createElement(index$2['default'], {
    show: visible,
    className: classnames__default['default'](baseClass, {
      [`${baseClass}--${theme}`]: !!theme
    }, className),
    style: {
      width: index$3.addUnit(width)
    },
    onClickOverlay: onClickOverlay,
    onOpen: onOpen,
    onOpened: onOpened,
    onClose: onClose,
    onClosed: onClosed
  }, renderTitle, renderContent, theme === 'round-button' ? renderRoundButtons : renderButtons);
};

exports.default = Dialog;
