'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var ReactDOM = require('react-dom');
var reactTransitionGroup = require('react-transition-group');
var classnames = require('classnames');
var index$2 = require('../icon/index.js');
var index = require('../utils/index.js');
var index$1 = require('../overlay/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var ReactDOM__default = /*#__PURE__*/_interopDefaultLegacy(ReactDOM);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const context = {
  zIndex: 2000
};
const baseClass = 'r-popup';
const Popup = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    show = false,
    zIndex = 2000,
    duration = 300,
    teleport,
    overlay = true,
    overlayStyle = {},
    overlayClass,
    style = {},
    className,
    round = false,
    closeable = false,
    closeIcon = 'cross',
    safeAreaInsetBottom = false,
    closeIconPosition = 'top-right',
    position = 'center',
    closeOnClickOverlay = true,
    onClickOverlay,
    // transition,
    // onClick,
    onClickCloseIcon,
    onOpen,
    onOpened,
    onClose,
    onClosed,
    children
  } = props;
  const [visible, setVisible] = React.useState(false); // 初始化

  const zIndexRef = React.useRef(zIndex || context.zIndex);
  const popupRef = React.useRef(null); // 需在该处监听show的变化，用以显示（隐藏）遮罩或（和）弹出层;

  React.useEffect(() => {
    setVisible(show);
  }, [show]); // 行内样式

  const customStyle = React.useMemo(() => {
    const InnerStyle = {
      zIndex: zIndexRef.current
    };

    if (index.isDef(duration)) {
      const key = position === 'center' ? 'animationDuration' : 'transitionDuration';
      InnerStyle[key] = `${duration}ms`;
    }

    return {
      zIndex: zIndexRef.current,
      ...InnerStyle,
      ...style
    };
  }, [duration, position, style]);
  const handleClose = React.useCallback(() => {
    onClose == null ? void 0 : onClose();
  }, [onClose]); // 点击遮罩，关闭弹出层。

  const clickOverlay = React.useCallback(() => {
    onClickOverlay == null ? void 0 : onClickOverlay();

    if (closeOnClickOverlay) {
      handleClose();
    }
  }, [closeOnClickOverlay, handleClose, onClickOverlay]); // 渲染遮罩层

  const renderOverlay = () => {
    if (overlay) {
      return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
        show: visible,
        className: overlayClass,
        customStyle: overlayStyle,
        zIndex: zIndexRef.current,
        duration: +duration,
        onClick: clickOverlay
      });
    }

    return null;
  }; // 点击关闭icon，关闭弹出层。


  const handleClickCloseIcon = e => {
    onClickCloseIcon == null ? void 0 : onClickCloseIcon(e);
  };

  const renderCloseIcon = () => {
    const classString = classnames__default['default'](`${baseClass}__close-icon`, `${baseClass}__close-icon--${closeIconPosition}`);

    if (closeable) {
      return /*#__PURE__*/React__default['default'].createElement(index$2['default'], {
        name: closeIcon,
        className: classString,
        onClick: handleClickCloseIcon
      });
    }

    return null;
  }; // 渲染弹出层


  const renderPopup = () => {
    return /*#__PURE__*/React__default['default'].createElement("div", {
      ref: popupRef,
      style: customStyle,
      className: classnames__default['default'](baseClass, `${baseClass}--${position}`, {
        [`${baseClass}--${position}--round`]: round,
        [`${baseClass}--safe-area-inset-bottom`]: safeAreaInsetBottom
      }, className)
    }, children, renderCloseIcon());
  };

  const handleOpen = el => {
    onOpen == null ? void 0 : onOpen(el);
  };

  const handleOpened = el => {
    onOpened == null ? void 0 : onOpened(el);
  };

  const handleClosed = el => {
    onClosed == null ? void 0 : onClosed(el);
  };

  const handleShow = el => {
    el.style.display = 'block';
  };

  const handleHide = el => {
    el.style.display = 'none';
  };

  const renderTransition = () => {
    // 根据弹出层位置设置动画
    const name = position === 'center' ? 'anmimate' : `r-slide-${position}`;
    return /*#__PURE__*/React__default['default'].createElement(reactTransitionGroup.CSSTransition, {
      in: visible,
      timeout: +duration,
      classNames: name,
      onEnter: el => handleOpen(el),
      onEntering: el => handleShow(el),
      onEntered: el => handleOpened == null ? void 0 : handleOpened(el),
      onExit: () => handleClose(),
      onExiting: el => name === 'anmimate' ? handleHide(el) : null,
      onExited: el => handleClosed(el)
    }, renderPopup());
  };

  const renderUI = () => {
    return /*#__PURE__*/React__default['default'].createElement("div", {
      className: "popup-wrapper",
      ref: ref
    }, renderOverlay(), renderTransition());
  };

  const renderPortal = () => {
    const ele = index.getMountContanier(document.querySelector(teleport));
    return teleport ? /*#__PURE__*/ReactDOM__default['default'].createPortal(renderUI(), ele) : renderUI();
  };

  return /*#__PURE__*/React__default['default'].createElement(React__default['default'].Fragment, null, renderPortal());
});
Popup.displayName = 'Popup';

exports.default = Popup;
