'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var React = require('react');
var classnames = require('classnames');
var index$1 = require('../loading/index.js');
var index = require('../utils/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const baseClass = 'r-switch';
const Switch = /*#__PURE__*/React.forwardRef((props, ref) => {
  const {
    model = false,
    loading = false,
    disabled = false,
    size = '30',
    activeColor = '#1989fa',
    inactiveColor = '#ffffff',
    activeValue = true,
    inactiveValue = false,
    onChange,
    onClick
  } = props;

  const isChecked = () => model === activeValue;

  const renderLoading = () => {
    if (loading) {
      const color = isChecked() ? activeColor : inactiveColor;
      return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
        className: classnames__default['default'](`${baseClass}__loading`),
        color: color
      });
    }

    return null;
  };

  const handleClick = e => {
    if (!disabled && !loading) {
      const newValue = isChecked() ? inactiveValue : activeValue;
      onChange == null ? void 0 : onChange(newValue);
      onClick == null ? void 0 : onClick(e);
    }
  };

  const checked = isChecked();
  const style = {
    fontSize: index.addUnit(size),
    backgroundColor: checked ? activeColor : inactiveColor
  };
  const classString = classnames__default['default'](baseClass, {
    [`${baseClass}--on`]: checked,
    [`${baseClass}--loading`]: loading,
    [`${baseClass}--disabled`]: disabled
  });
  return /*#__PURE__*/React__default['default'].createElement("div", {
    ref: ref,
    role: "switch",
    className: classString,
    style: style,
    "aria-checked": checked,
    onClick: handleClick
  }, /*#__PURE__*/React__default['default'].createElement("div", {
    className: classnames__default['default'](`${baseClass}__node`)
  }, renderLoading()));
});
Switch.displayName = 'Switch';

exports.default = Switch;
