'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var _extends = require('@babel/runtime/helpers/extends');
var _assertThisInitialized = require('@babel/runtime/helpers/assertThisInitialized');
var _inheritsLoose = require('@babel/runtime/helpers/inheritsLoose');
var _defineProperty = require('@babel/runtime/helpers/defineProperty');
var React = require('react');
var ReactDOM = require('react-dom');
var classnames = require('classnames');
var index$2 = require('../utils/index.js');
var index = require('../icon/index.js');
var index$1 = require('../loading/index.js');
var index$3 = require('../popup/index.js');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var _extends__default = /*#__PURE__*/_interopDefaultLegacy(_extends);
var _assertThisInitialized__default = /*#__PURE__*/_interopDefaultLegacy(_assertThisInitialized);
var _inheritsLoose__default = /*#__PURE__*/_interopDefaultLegacy(_inheritsLoose);
var _defineProperty__default = /*#__PURE__*/_interopDefaultLegacy(_defineProperty);
var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var ReactDOM__default = /*#__PURE__*/_interopDefaultLegacy(ReactDOM);
var classnames__default = /*#__PURE__*/_interopDefaultLegacy(classnames);

const isToastProps = content => {
  return !!content && typeof content === 'object';
};

const parseObject = message => {
  return typeof message === 'string' ? {
    message
  } : message;
};

let Toast = /*#__PURE__*/function (_PureComponent) {
  _inheritsLoose__default['default'](Toast, _PureComponent);

  function Toast(...args) {
    var _this;

    _this = _PureComponent.call(this, ...args) || this;

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "state", {
      // eslint-disable-next-line react/destructuring-assignment
      show: _this.props.show
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "timer", 0);

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "renderIcon", () => {
      const {
        icon,
        type,
        iconPrefix,
        loadingType
      } = _this.props;
      const hasIcon = icon || type === 'success' || type === 'fail';

      if (hasIcon) {
        return /*#__PURE__*/React__default['default'].createElement(index['default'], {
          name: icon || type,
          classPrefix: iconPrefix,
          className: classnames__default['default'](`${Toast.baseClass}__icon`)
        });
      }

      if (type === 'loading') {
        return /*#__PURE__*/React__default['default'].createElement(index$1['default'], {
          type: loadingType,
          className: classnames__default['default'](`${Toast.baseClass}__loading`)
        });
      }

      return null;
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "renderMessage", () => {
      const {
        message,
        type
      } = _this.props;

      if (index$2.isDef(message) && message !== '') {
        return type === 'html' ? /*#__PURE__*/React__default['default'].createElement("div", {
          className: classnames__default['default'](`${Toast.baseClass}__html`) // eslint-disable-next-line react/no-danger
          ,
          dangerouslySetInnerHTML: {
            __html: message
          }
        }) : /*#__PURE__*/React__default['default'].createElement("div", {
          className: classnames__default['default'](`${Toast.baseClass}__text`)
        }, message);
      }

      return null;
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "handleOpened", () => {
      const {
        onOpened
      } = _this.props;
      onOpened == null ? void 0 : onOpened();
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "handleColse", () => {
      const {
        onClose
      } = _this.props;

      if (Toast.toastDom) {
        Toast.toastContainer.removeChild(Toast.toastDom);
        Toast.toastDom = null;
      }

      onClose == null ? void 0 : onClose();
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "_hide", () => {
      _this.setState({
        show: false
      });
    });

    _defineProperty__default['default'](_assertThisInitialized__default['default'](_this), "shutdown", () => {
      const {
        duration
      } = _this.props;

      if (duration > 0) {
        _this.timer = window.setTimeout(() => {
          // eslint-disable-next-line no-underscore-dangle
          _this._hide();

          clearTimeout(_this.timer);
        }, duration);
      }
    });

    return _this;
  }

  var _proto = Toast.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.shutdown();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    const {
      show
    } = this.props;

    if (prevProps.show !== show) {
      if (show === true) {
        // eslint-disable-next-line react/no-did-update-set-state
        this.setState({
          show: true
        });
        this.shutdown();
      } else {
        clearTimeout(this.timer);
        this.shutdown();
      }
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    clearTimeout(this.timer);
  };

  _proto.render = function render() {
    const {
      icon,
      type,
      position,
      duration,
      overlay,
      ...rest
    } = this.props;
    const {
      show
    } = this.state;
    const positionCls = classnames__default['default'](Toast.baseClass, `${Toast.baseClass}--${position}`, {
      [`${Toast.baseClass}--text`]: type === 'text' || type === 'html',
      [`${Toast.baseClass}--${type}`]: !icon
    });
    return /*#__PURE__*/React__default['default'].createElement(index$3['default'], _extends__default['default']({
      position: "center",
      duration: duration,
      overlay: overlay,
      onOpened: this.handleOpened,
      onClose: this.handleColse
    }, rest, {
      className: positionCls,
      show: show
    }), this.renderIcon(), this.renderMessage());
  };

  return Toast;
}(React.PureComponent);

_defineProperty__default['default'](Toast, "baseClass", 'r-toast');

_defineProperty__default['default'](Toast, "defaultOptions", {
  icon: '',
  type: 'text',
  message: '',
  className: '',
  overlay: false,
  onClose: undefined,
  onOpened: undefined,
  duration: 2000,
  // teleport: '#root',
  iconSize: undefined,
  iconPrefix: 'r-icon',
  position: 'center',
  forbidClick: false,
  loadingType: undefined,
  overlayClass: '',
  overlayStyle: undefined,
  closeOnClick: false,
  closeOnClickOverlay: false
});

_defineProperty__default['default'](Toast, "toastDom", void 0);

_defineProperty__default['default'](Toast, "toastContainer", void 0);

_defineProperty__default['default'](Toast, "hideHelper", void 0);

_defineProperty__default['default'](Toast, "show", options => {
  Toast.unmountNode();

  if (!Toast.toastDom) {
    Toast.toastDom = document.createElement('div');

    if (isToastProps(options)) {
      Toast.toastDom.classList.add('r-toast-contanier');
    }

    if (options.className) {
      Toast.toastDom.classList.add(options.className);
    }

    const teleport = isToastProps(options) && typeof options.teleport === 'string' ? document.querySelector(options.teleport) : options.teleport;
    Toast.toastContainer = teleport ? index$2.getMountContanier(teleport) : index$2.getMountContanier();
    Toast.toastContainer.appendChild(Toast.toastDom);
  }

  if (Toast.toastDom) {
    const props = Object.assign(Toast.defaultOptions, parseObject(options), {
      show: true
    });

    Toast.hideHelper = () => {
      ReactDOM__default['default'].render( /*#__PURE__*/React__default['default'].createElement(Toast, _extends__default['default']({}, props, {
        show: false
      })), Toast.toastDom);
    }; // eslint-disable-next-line react/no-render-return-value


    return ReactDOM__default['default'].render( /*#__PURE__*/React__default['default'].createElement(Toast, props), Toast.toastDom);
  }
});

_defineProperty__default['default'](Toast, "close", () => {
  if (Toast.toastDom) {
    Toast.hideHelper();
  }

  return null;
});

_defineProperty__default['default'](Toast, "unmountNode", () => {
  const {
    toastDom,
    toastContainer
  } = Toast;

  if (toastDom) {
    toastContainer.removeChild(toastDom);
    Toast.toastDom = null;
  }
});

exports.default = Toast;
