'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

const noop = () => ({}); // 判断其参数是否是数字

const isNumeric = val => {
  return /^\d+(\.\d+)?$/.test(val);
}; // 判断其参数是否是非数字值

const isDef = val => {
  return val !== undefined && val !== null;
}; // 添加单位

const addUnit = value => {
  if (!isDef(value)) {
    return undefined;
  } // eslint-disable-next-line no-param-reassign


  value = String(value);
  return isNumeric(value) ? `${value}px` : value;
}; // 获取宽高
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types

const getSizeStyle = originSize => {
  if (isDef(originSize)) {
    const size = addUnit(originSize);
    return {
      width: size,
      height: size
    };
  }

  return {};
}; // 阻止默认事件

const inBrowser = () => {
  return typeof window !== 'undefined';
}; // 获取挂载的容器

const getMountContanier = contanier => {
  if (contanier) {
    if (typeof contanier === 'function') {
      return contanier();
    }

    if (typeof contanier === 'object' && contanier instanceof HTMLElement) {
      return contanier;
    }
  }

  return document.body;
}; // 将组件中传入的配置项(组件属性)对应的key/value赋给新对象。

const pick = (prop, keys) => {
  return keys.reduce((target, key) => {
    // eslint-disable-next-line no-param-reassign
    target[key] = prop[key];
    return target;
  }, {});
};
const isObject = val => {
  return val !== null && typeof val === 'object';
}; // eslint-disable-next-line @typescript-eslint/ban-types

const isFunction = val => {
  return val !== null && typeof val === 'function';
}; // 判断是否是Promise函数

const isPromise = val => {
  return isObject(val) && isFunction(val.then) && isFunction(val.catch);
};
const isEmptyValue = value => {
  if (Array.isArray(value)) {
    return !value.length;
  }

  if (value === 0) {
    return false;
  }

  return !value;
};

const trimExtraChar = (value, char, regExp) => {
  const index = value.indexOf(char);

  if (index === -1) {
    return value;
  }

  if (char === '-' && index !== 0) {
    return value.slice(0, index);
  }

  return value.slice(0, index + 1) + value.slice(index).replace(regExp, '');
};
const formatNumber = (value, allowDot = true, allowMinus = true) => {
  if (allowDot) {
    // eslint-disable-next-line no-param-reassign
    value = trimExtraChar(value, '.', /\./g);
  } else {
    // eslint-disable-next-line no-param-reassign
    value = value.split('.')[0];
  }

  if (allowMinus) {
    // eslint-disable-next-line no-param-reassign
    value = trimExtraChar(value, '-', /-/g);
  } else {
    // eslint-disable-next-line no-param-reassign
    value = value.replace(/-/, '');
  }

  const regExp = allowDot ? /[^-0-9.]/g : /[^-0-9]/g;
  return value.replace(regExp, '');
};
const trigger = (target, type) => {
  const inputEvent = document.createEvent('HTMLEvents');
  inputEvent.initEvent(type, true, true);
  target.dispatchEvent(inputEvent);
};
const runSyncRule = (value, rule) => {
  if (rule.required && isEmptyValue(value)) {
    return false;
  }

  if (rule.pattern && !rule.pattern.test(String(value))) {
    return false;
  }

  return true;
};

exports.addUnit = addUnit;
exports.formatNumber = formatNumber;
exports.getMountContanier = getMountContanier;
exports.getSizeStyle = getSizeStyle;
exports.inBrowser = inBrowser;
exports.isDef = isDef;
exports.isEmptyValue = isEmptyValue;
exports.isFunction = isFunction;
exports.isNumeric = isNumeric;
exports.isObject = isObject;
exports.isPromise = isPromise;
exports.noop = noop;
exports.pick = pick;
exports.runSyncRule = runSyncRule;
exports.trigger = trigger;
exports.trimExtraChar = trimExtraChar;
