import _extends from '@babel/runtime/helpers/esm/extends';
import React, { useState, useEffect, useCallback, useMemo } from 'react';
import classnames from 'classnames';
import Icon from '../icon/index.js';
import Loading from '../loading/index.js';
import Popup from '../popup/index.js';
import { defultPopupSharedProps } from '../popup/props.js';
import { isDef, pick } from '../utils/index.js';

const baseClass = 'r-action-sheet';

const ActionSheet = props => {
  const {
    show = false,
    actions,
    title,
    cancelText,
    description,
    closeOnClickAction = true,
    round = true,
    closeable = true,
    closeIcon = 'cross',
    safeAreaInsetBottom,
    onSelect,
    onCancel,
    onOpen,
    onOpened,
    onClose,
    onClosed,
    onClickOverlay,
    children
  } = props;
  const [visible, setVisible] = useState(false);
  useEffect(() => {
    setVisible(show);
  }, [show]); // const popupDefaultPropKeys = Object.keys(defultProps);

  const popupDefaultPropKeys = Object.keys(defultPopupSharedProps);
  const handleCancel = useCallback(() => {
    setVisible(false);
    onCancel == null ? void 0 : onCancel();
  }, [onCancel]);
  const renderHeader = useMemo(() => {
    if (title) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(`${baseClass}__header`)
      }, title, closeable && /*#__PURE__*/React.createElement(Icon, {
        name: closeIcon,
        className: classnames(`${baseClass}__close`),
        onClick: handleCancel
      }));
    }

    return null;
  }, [title, closeable, closeIcon, handleCancel]);
  const renderCancelBtn = useMemo(() => {
    if (cancelText) {
      return /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("div", {
        className: classnames(`${baseClass}__gap`)
      }), /*#__PURE__*/React.createElement("button", {
        type: "button",
        className: classnames(`${baseClass}__cancel`),
        onClick: handleCancel
      }, cancelText));
    }

    return null;
  }, [cancelText, handleCancel]);
  const renderOption = useCallback((item, index) => {
    const {
      name,
      color,
      subname,
      loading,
      callback,
      disabled,
      className
    } = item;
    const Content = loading ? /*#__PURE__*/React.createElement(Loading, {
      className: classnames(`${baseClass}__loading-icon`)
    }) : /*#__PURE__*/React.createElement(React.Fragment, null, /*#__PURE__*/React.createElement("span", {
      className: classnames(`${baseClass}__name`)
    }, name), subname && /*#__PURE__*/React.createElement("div", {
      className: classnames(`${baseClass}__subname`)
    }, subname)); // 点击选项

    const onClickItem = () => {
      if (disabled || loading) {
        return;
      }

      callback == null ? void 0 : callback(item); // 点击选项后触发

      onSelect == null ? void 0 : onSelect(item, index); // 在点击选项后关闭

      if (closeOnClickAction) {
        // 设置actionsheet的show的状态
        setVisible(false);
      }
    };

    return /*#__PURE__*/React.createElement("button", {
      type: "button",
      style: {
        color
      },
      className: classnames(`${baseClass}__item`, {
        [`${baseClass}__item--loading`]: loading,
        [`${baseClass}__item--disabled`]: disabled
      }, className),
      onClick: onClickItem,
      key: name
    }, Content);
  }, [onSelect, closeOnClickAction]);
  const renderOptions = useMemo(() => {
    if (actions) {
      return actions.map(renderOption);
    }

    return null;
  }, [actions, renderOption]);
  const renderDescription = useMemo(() => {
    return isDef(description) && description !== '' ? /*#__PURE__*/React.createElement("div", {
      className: classnames(`${baseClass}__description`)
    }, description) : /*#__PURE__*/React.createElement(React.Fragment, null);
  }, [description]);
  return /*#__PURE__*/React.createElement(Popup, _extends({
    className: classnames(`${baseClass}`)
  }, pick(props, popupDefaultPropKeys), {
    show: visible,
    round: round,
    position: "bottom",
    safeAreaInsetBottom: safeAreaInsetBottom,
    onClickOverlay: onClickOverlay,
    onOpen: onOpen,
    onOpened: onOpened,
    onClose: onClose,
    onClosed: onClosed
  }), renderHeader, renderDescription, /*#__PURE__*/React.createElement("div", {
    className: classnames(`${baseClass}__content`)
  }, renderOptions, children), renderCancelBtn);
};

export default ActionSheet;
