import React, { useRef } from 'react';
import classnames from 'classnames';
import { isDef } from '../utils/index.js';

const baseClass = 'r-badge';

const Badge = props => {
  const {
    dot,
    max,
    content,
    color,
    tag = 'div',
    className,
    offset,
    style,
    children,
    onClick
  } = props;
  const Tag = tag;
  const isIcon = useRef(false);

  const hasContent = () => {
    if (isIcon.current) {
      return true;
    }

    return isDef(content) && content !== '';
  };

  const renderContent = () => {
    if (!dot && hasContent()) {
      if (isIcon.current) {
        return React.Children.map(children, child => {
          var _child$type;

          if ((child == null ? void 0 : (_child$type = child.type) == null ? void 0 : _child$type.name) === 'Icon') {
            return child;
          }

          return null;
        });
      }
    }

    if (isDef(max) && isDef(content) && Number(content) > Number(max)) {
      const maxNum = Number(max);
      return `${maxNum}+`;
    }

    return content;
  };

  const renderBadge = () => {
    if (hasContent() || dot) {
      const styleProperties = {
        background: color
      };

      if (offset) {
        const [x, y] = offset;

        if (content) {
          styleProperties.top = `${y}px`;
          styleProperties.right = `${-x}px`;
        } else {
          styleProperties.marginTop = `${y}px`;
          styleProperties.marginLeft = `${x}px`;
        }
      }

      return /*#__PURE__*/React.createElement("div", {
        className: classnames(baseClass, {
          [`${baseClass}--fixed`]: !!children,
          [`${baseClass}--dot`]: dot
        }),
        style: styleProperties
      }, renderContent());
    }

    return null;
  };

  const withoutChildren = () => {
    return renderBadge();
  };

  const handleClick = e => {
    onClick == null ? void 0 : onClick(e);
  };

  const hasChildren = () => {
    return /*#__PURE__*/React.createElement(Tag, {
      className: classnames(`${baseClass}__wrapper`, className),
      onClick: handleClick,
      style: style
    }, React.Children.map(children, child => {
      var _child$type2;

      if ((child == null ? void 0 : (_child$type2 = child.type) == null ? void 0 : _child$type2.name) === 'Icon') {
        isIcon.current = true;
      }

      return child;
    }), renderBadge());
  };

  return /*#__PURE__*/React.createElement(React.Fragment, null, children ? hasChildren() : withoutChildren());
};

export default Badge;
