import React, { useMemo, useCallback } from 'react';
import classnames from 'classnames';
import Loading from '../loading/index.js';
import Icon from '../icon/index.js';

const baseClass = 'r-button';

const Button = props => {
  const {
    type = 'default',
    plain = false,
    disabled = false,
    loading = false,
    round = false,
    square = false,
    block = false,
    hairline = false,
    size = 'normal',
    loadingType = 'circular',
    loadingText,
    loadingSize = '16px',
    text,
    color,
    className,
    tag = 'button',
    nativeType,
    onClick,
    icon,
    iconPrefix = 'r-icon',
    iconPosition = 'left',
    children
  } = props;
  const Tag = tag || 'button';
  const Cls = classnames( // `${baseClass}`],
  baseClass, {
    [`${baseClass}--${type}`]: !!type,
    [`${baseClass}--${size}`]: !!size,
    [`${baseClass}--plain`]: plain,
    [`${baseClass}--disabled`]: disabled,
    [`${baseClass}--loading`]: loading,
    [`${baseClass}--round`]: round,
    [`${baseClass}--square`]: square,
    [`${baseClass}--block`]: block,
    [`${baseClass}--hairline`]: hairline,
    [`${baseClass}__${icon}`]: !!icon
  }, className);
  const renderIcon = useMemo(() => {
    if (loading) {
      return /*#__PURE__*/React.createElement(Loading, {
        color: color,
        size: loadingSize,
        type: loadingType
      });
    }

    if (icon) {
      return /*#__PURE__*/React.createElement(Icon, {
        className: classnames(`${baseClass}__icon`),
        classPrefix: iconPrefix,
        color: color,
        name: icon
      });
    }

    return null;
  }, [loading, icon, loadingType, loadingSize, color, iconPrefix]);
  const renderContent = useMemo(() => {
    let content;

    if (loading) {
      content = loadingText;
    } else {
      content = children || text;
    }

    if (content) {
      return /*#__PURE__*/React.createElement("span", {
        className: classnames(`${baseClass}__text`)
      }, content);
    }

    return null;
  }, [loading, loadingText, text, children]);
  const getStyle = useCallback(() => {
    if (color) {
      const style = {};
      style.color = plain ? color : 'white';

      if (!plain) {
        // 为了使linear-gradient起作用，请用background 代替 backgroundColor
        style.background = color;
        style.border = 'none';
      } // 当是渐变色是，去掉边框。


      if (color.indexOf('gradient') !== -1) {
        style.border = 'none';
      } else {
        style.borderColor = color;
      }

      return style;
    }

    return null;
  }, [color, plain]);

  const handleClick = e => {
    if (!disabled || !loading) {
      onClick == null ? void 0 : onClick(e);
    }
  };

  return /*#__PURE__*/React.createElement(Tag, {
    className: Cls,
    disabled: disabled,
    onClick: handleClick,
    style: getStyle(),
    type: nativeType
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(`${baseClass}__content`)
  }, iconPosition === 'left' && renderIcon, renderContent, iconPosition === 'right' && renderIcon));
};

export default Button;
