import React, { forwardRef, useMemo } from 'react';
import classnames from 'classnames';
import { isDef } from '../utils/index.js';
import Icon from '../icon/index.js';

const baseClass = 'r-cell';
const Cell = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    icon,
    size,
    title,
    value,
    label,
    center = false,
    isLink = false,
    required = false,
    iconPrefix = 'r-icon',
    valueClass,
    labelClass,
    titleClass,
    titleStyle,
    arrowDirection = 'right',
    border = true,
    clickable = true,
    className,
    onClick,
    children
  } = props;
  const isClickable = clickable != null ? clickable : isLink;
  const renderLabel = useMemo(() => {
    const showLabel = isDef(label);

    if (showLabel) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(`${baseClass}__label`, labelClass)
      }, label);
    }

    return null;
  }, [label, labelClass]);
  const renderTitle = useMemo(() => {
    if (isDef(title)) {
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(`${baseClass}__title`, titleClass),
        style: titleStyle
      }, /*#__PURE__*/React.createElement("span", null, title), renderLabel);
    }

    return null;
  }, [title, titleStyle, titleClass, renderLabel]);
  const renderValue = useMemo(() => {
    const hasValue = children || isDef(value);

    if (hasValue) {
      const hasTitle = isDef(title);
      return /*#__PURE__*/React.createElement("div", {
        className: classnames(`${baseClass}__value`, {
          [`${baseClass}__value--alone`]: !hasTitle
        }, valueClass)
      }, children || /*#__PURE__*/React.createElement("span", null, value));
    }

    return null;
  }, [valueClass, title, value, children]);
  const renderLeftIcon = useMemo(() => {
    if (icon) {
      return /*#__PURE__*/React.createElement(Icon, {
        name: icon,
        className: classnames(`${baseClass}__left-icon`),
        classPrefix: iconPrefix
      });
    }

    return null;
  }, [icon, iconPrefix]);
  const renderRightIcon = useMemo(() => {
    if (isLink) {
      const name = arrowDirection ? `arrow-${arrowDirection}` : 'arrow';
      return /*#__PURE__*/React.createElement(Icon, {
        name: name,
        className: classnames(`${baseClass}__right-icon`)
      });
    }

    return null;
  }, [isLink, arrowDirection]);

  const handleClick = e => {
    onClick == null ? void 0 : onClick(e);
  };

  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    className: classnames(baseClass, {
      [`${baseClass}--large`]: !!size,
      [`${baseClass}--center`]: center,
      [`${baseClass}--required`]: required,
      [`${baseClass}--clickable`]: isClickable,
      [`${baseClass}--borderless`]: !border
    }, className),
    role: clickable ? 'button' : undefined // eslint-disable-next-line jsx-a11y/no-noninteractive-tabindex
    ,
    tabIndex: clickable ? 0 : undefined,
    onClick: handleClick
  }, renderLeftIcon, renderTitle, renderValue, renderRightIcon);
});
Cell.displayName = 'Cell';

export default Cell;
