import _extends from '@babel/runtime/helpers/esm/extends';
import React, { forwardRef, useContext, useState, useEffect, useImperativeHandle } from 'react';
import { CheckboxGroupContext } from '../checkbox-group/index.js';
import Checker from './checker.js';

const Checkbox = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    name,
    model = false,
    bindGroup = true,
    onChange
  } = props; // 获取共享上下文

  const parent = useContext(CheckboxGroupContext); // 初始化状态

  const [modelValue, setModelValue] = useState(model);
  useEffect(() => {
    onChange == null ? void 0 : onChange(modelValue);
  }, [modelValue, onChange]); // 更新父组件的model值(当有父组件时)

  const updateParentModel = checked => {
    const {
      model,
      max,
      onChange
    } = parent;

    if (checked) {
      // 判断父组件的model值的数量是否大于设置的max值
      const overLimit = max && (model == null ? void 0 : model.length) >= max;

      if (!overLimit && (model == null ? void 0 : model.indexOf(name)) === -1) {
        setModelValue(checked);
        model.push(name);

        if (bindGroup) {
          onChange == null ? void 0 : onChange(model);
        }
      }
    } else {
      const index = model.indexOf(name);

      if (index !== -1) {
        setModelValue(checked);
        model.splice(index, 1);

        if (bindGroup) {
          onChange == null ? void 0 : onChange(model);
        }
      }
    }
  };

  const toggle = (newVal = !modelValue) => {
    if (parent && bindGroup) {
      updateParentModel(newVal);
    } else {
      setModelValue(newVal);
    }
  };

  useImperativeHandle(ref, () => ({
    toggle
  }));
  return /*#__PURE__*/React.createElement(Checker, _extends({
    ref: ref,
    baseClass: "r-checkbox",
    role: "checkbox",
    parent: parent,
    checked: modelValue,
    onToggle: toggle
  }, props));
});
Checkbox.displayName = 'Checkbox';

export default Checkbox;
