import React, { createContext, forwardRef, useImperativeHandle } from 'react';
import classnames from 'classnames';

const FormContenxt = /*#__PURE__*/createContext(null);
const baseClass = 'r-form';
const Form = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    validateFirst = false,
    scrollToError = false,
    onFailed,
    onSubmit,
    children
  } = props;

  const getFieldsByNames = names => {
    if (names) {
      return React.Children.toArray(children).filter(field => names.indexOf(field.name) !== -1);
    }

    return children;
  }; // 按顺序校验


  const validateSeq = names => {
    return new Promise((resolve, reject) => {
      const errors = [];
      const fields = getFieldsByNames(names);
      fields.reduce((promise, field) => promise.then(() => {
        if (!errors.length) {
          var _field$ref, _field$ref$current;

          return (_field$ref = field.ref) == null ? void 0 : (_field$ref$current = _field$ref.current) == null ? void 0 : _field$ref$current.validate().then(error => {
            if (error) {
              errors.push(error);
            }
          });
        }
      }), Promise.resolve()).then(() => {
        if (errors.length) {
          reject(errors);
        } else {
          resolve();
        }
      });
    });
  };

  const validateAll = names => {
    return new Promise((resolve, reject) => {
      const fields = getFieldsByNames(names);
      Promise.all(fields == null ? void 0 : fields.map(item => {
        var _item$ref, _item$ref$current;

        return (_item$ref = item.ref) == null ? void 0 : (_item$ref$current = _item$ref.current) == null ? void 0 : _item$ref$current.validate();
      })).then(errors => {
        // errors = errors.filter((item) => item);
        errors.filter(item => item);

        if (errors.length) {
          reject(errors);
        } else {
          resolve();
        }
      });
    });
  };

  const validateField = name => {
    const matched = React.Children.map(children, item => {
      var _props;

      return (item == null ? void 0 : (_props = item.props) == null ? void 0 : _props.name) === name;
    });

    if (matched.length) {
      return new Promise((resolve, reject) => {
        var _matched$0$ref, _matched$0$ref$curren;

        (_matched$0$ref = matched[0].ref) == null ? void 0 : (_matched$0$ref$curren = _matched$0$ref.current) == null ? void 0 : _matched$0$ref$curren.validate().then(error => {
          if (error) {
            reject(error);
          } else {
            resolve();
          }
        });
      });
    }

    return Promise.reject();
  };

  const getValues = () => {
    return React.Children.toArray(children).reduce((form, item) => {
      var _field$type;

      const field = item;

      if ((field == null ? void 0 : (_field$type = field.type) == null ? void 0 : _field$type.displayName) === 'Field') {
        var _field$ref$current2;

        form[field == null ? void 0 : field.props.name] = (_field$ref$current2 = field.ref.current) == null ? void 0 : _field$ref$current2.formValue();
        return form;
      }

      return null;
    }, {});
  };

  const validate = name => {
    if (typeof name === 'string') {
      return validateField(name);
    }

    return validateFirst ? validateSeq(name) : validateAll(name);
  };

  const resetValidation = name => {
    if (typeof name === 'string') {
      name = [name];
    }

    const fields = getFieldsByNames(name);
    fields.forEach(item => {
      var _item$ref2, _item$ref2$current;

      (_item$ref2 = item.ref) == null ? void 0 : (_item$ref2$current = _item$ref2.current) == null ? void 0 : _item$ref2$current.resetValidation();
    });
  };

  const scrollToField = (name, options) => {
    React.Children.toArray(children).some(child => {
      var _item$props;

      const item = child;

      if ((item == null ? void 0 : (_item$props = item.props) == null ? void 0 : _item$props.name) === name) {
        var _item$ref3, _item$ref3$current;

        (_item$ref3 = item.ref) == null ? void 0 : (_item$ref3$current = _item$ref3.current) == null ? void 0 : _item$ref3$current.scrollIntoView(options);
        return true;
      }

      return false;
    });
  };

  const submit = () => {
    const values = getValues();
    validate().then(() => {
      onSubmit == null ? void 0 : onSubmit(values);
    }).catch(errors => {
      onFailed == null ? void 0 : onFailed({
        values,
        errors
      });

      if (scrollToError && errors[0].name) {
        scrollToField(errors[0].name);
      }
    });
  };

  const handleSubmit = event => {
    event.preventDefault();
    submit();
  };

  useImperativeHandle(ref, () => ({
    resetValidation,
    submit,
    validate,
    scrollToField
  }));
  return /*#__PURE__*/React.createElement("form", {
    className: classnames(baseClass),
    onSubmit: handleSubmit,
    ref: ref
  }, /*#__PURE__*/React.createElement(FormContenxt.Provider, {
    value: props
  }, children));
});
Form.displayName = 'Form';

export default Form;
export { FormContenxt };
