import React, { useMemo } from 'react';
import classnames from 'classnames';
import { addUnit, getSizeStyle } from '../utils/index.js';

const Loading = props => {
  const baseClass = 'r-loading';
  const {
    color,
    type = 'circular',
    size = '30px',
    text = '',
    textSize = '14px',
    textColor,
    vertical = false,
    className
  } = props;
  const SpinIcon = [];

  for (let i = 0; i < 12; i++) {
    SpinIcon.push( /*#__PURE__*/React.createElement("i", {
      key: i
    }));
  }

  const spinnerStyle = () => ({
    color,
    ...getSizeStyle(size)
  });

  const CircularIcon = /*#__PURE__*/React.createElement("svg", {
    className: classnames(`${baseClass}__circular`),
    viewBox: "25 25 50 50"
  }, /*#__PURE__*/React.createElement("circle", {
    cx: "50",
    cy: "50",
    fill: "none",
    r: "20"
  }));
  const renderText = useMemo(() => {
    return /*#__PURE__*/React.createElement("span", {
      className: classnames(`${baseClass}__text`),
      style: {
        fontSize: addUnit(textSize),
        color: textColor != null ? textColor : color
      }
    }, text);
  }, [text, textSize, textColor, color]);
  const classStringWrapper = classnames(baseClass, `${baseClass}__spinner--${type}`, {
    [`${baseClass}--vertical`]: !!vertical
  }, className);
  const classStringInner = classnames(`${baseClass}__spinner`, `${baseClass}__spinner--${type}`);
  return /*#__PURE__*/React.createElement("div", {
    className: classStringWrapper
  }, /*#__PURE__*/React.createElement("span", {
    className: classStringInner,
    style: spinnerStyle()
  }, type === 'spinner' ? SpinIcon : CircularIcon), renderText);
};

export default Loading;
