import React, { useState, useEffect, useMemo } from 'react';
import { CSSTransition } from 'react-transition-group';
import classnames from 'classnames';

const baseClass = 'r-overlay'; // const BODY_LOCK_CLASS = 'r-overflow-hidden';

const Overlay = props => {
  const {
    show = false,
    zIndex = 1,
    duration = 300,
    customStyle,
    onClick,
    children
  } = props;
  const [visible, setVisible] = useState(false);
  const [display, setDisplay] = useState({
    display: 'none'
  });
  useEffect(() => {
    setVisible(show);
    setDisplay({
      display: visible ? 'block' : 'none'
    });
  }, [show]);

  const handleClick = e => {
    onClick == null ? void 0 : onClick(e);
  };

  const style = useMemo(() => {
    return {
      zIndex: zIndex !== undefined ? +zIndex : undefined,
      ...display,
      ...customStyle
    };
  }, [display, zIndex, customStyle]);

  const handleStatus = el => {
    el.style.display = show ? 'block' : 'none';
  };

  return /*#__PURE__*/React.createElement(CSSTransition, {
    in: visible,
    classNames: "animate",
    timeout: +duration,
    onEnter: el => handleStatus(el),
    onExited: el => handleStatus(el)
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(baseClass),
    onClick: handleClick,
    style: style
  }, children));
};

export default Overlay;
