import React, { forwardRef } from 'react';
import classnames from 'classnames';
import Loading from '../loading/index.js';
import { addUnit } from '../utils/index.js';

const baseClass = 'r-switch';
const Switch = /*#__PURE__*/forwardRef((props, ref) => {
  const {
    model = false,
    loading = false,
    disabled = false,
    size = '30',
    activeColor = '#1989fa',
    inactiveColor = '#ffffff',
    activeValue = true,
    inactiveValue = false,
    onChange,
    onClick
  } = props;

  const isChecked = () => model === activeValue;

  const renderLoading = () => {
    if (loading) {
      const color = isChecked() ? activeColor : inactiveColor;
      return /*#__PURE__*/React.createElement(Loading, {
        className: classnames(`${baseClass}__loading`),
        color: color
      });
    }

    return null;
  };

  const handleClick = e => {
    if (!disabled && !loading) {
      const newValue = isChecked() ? inactiveValue : activeValue;
      onChange == null ? void 0 : onChange(newValue);
      onClick == null ? void 0 : onClick(e);
    }
  };

  const checked = isChecked();
  const style = {
    fontSize: addUnit(size),
    backgroundColor: checked ? activeColor : inactiveColor
  };
  const classString = classnames(baseClass, {
    [`${baseClass}--on`]: checked,
    [`${baseClass}--loading`]: loading,
    [`${baseClass}--disabled`]: disabled
  });
  return /*#__PURE__*/React.createElement("div", {
    ref: ref,
    role: "switch",
    className: classString,
    style: style,
    "aria-checked": checked,
    onClick: handleClick
  }, /*#__PURE__*/React.createElement("div", {
    className: classnames(`${baseClass}__node`)
  }, renderLoading()));
});
Switch.displayName = 'Switch';

export default Switch;
