import _extends from '@babel/runtime/helpers/esm/extends';
import _assertThisInitialized from '@babel/runtime/helpers/esm/assertThisInitialized';
import _inheritsLoose from '@babel/runtime/helpers/esm/inheritsLoose';
import _defineProperty from '@babel/runtime/helpers/esm/defineProperty';
import React, { PureComponent } from 'react';
import ReactDOM from 'react-dom';
import classnames from 'classnames';
import { isDef, getMountContanier } from '../utils/index.js';
import Icon from '../icon/index.js';
import Loading from '../loading/index.js';
import Popup from '../popup/index.js';

const isToastProps = content => {
  return !!content && typeof content === 'object';
};

const parseObject = message => {
  return typeof message === 'string' ? {
    message
  } : message;
};

let Toast = /*#__PURE__*/function (_PureComponent) {
  _inheritsLoose(Toast, _PureComponent);

  function Toast(...args) {
    var _this;

    _this = _PureComponent.call(this, ...args) || this;

    _defineProperty(_assertThisInitialized(_this), "state", {
      // eslint-disable-next-line react/destructuring-assignment
      show: _this.props.show
    });

    _defineProperty(_assertThisInitialized(_this), "timer", 0);

    _defineProperty(_assertThisInitialized(_this), "renderIcon", () => {
      const {
        icon,
        type,
        iconPrefix,
        loadingType
      } = _this.props;
      const hasIcon = icon || type === 'success' || type === 'fail';

      if (hasIcon) {
        return /*#__PURE__*/React.createElement(Icon, {
          name: icon || type,
          classPrefix: iconPrefix,
          className: classnames(`${Toast.baseClass}__icon`)
        });
      }

      if (type === 'loading') {
        return /*#__PURE__*/React.createElement(Loading, {
          type: loadingType,
          className: classnames(`${Toast.baseClass}__loading`)
        });
      }

      return null;
    });

    _defineProperty(_assertThisInitialized(_this), "renderMessage", () => {
      const {
        message,
        type
      } = _this.props;

      if (isDef(message) && message !== '') {
        return type === 'html' ? /*#__PURE__*/React.createElement("div", {
          className: classnames(`${Toast.baseClass}__html`) // eslint-disable-next-line react/no-danger
          ,
          dangerouslySetInnerHTML: {
            __html: message
          }
        }) : /*#__PURE__*/React.createElement("div", {
          className: classnames(`${Toast.baseClass}__text`)
        }, message);
      }

      return null;
    });

    _defineProperty(_assertThisInitialized(_this), "handleOpened", () => {
      const {
        onOpened
      } = _this.props;
      onOpened == null ? void 0 : onOpened();
    });

    _defineProperty(_assertThisInitialized(_this), "handleColse", () => {
      const {
        onClose
      } = _this.props;

      if (Toast.toastDom) {
        Toast.toastContainer.removeChild(Toast.toastDom);
        Toast.toastDom = null;
      }

      onClose == null ? void 0 : onClose();
    });

    _defineProperty(_assertThisInitialized(_this), "_hide", () => {
      _this.setState({
        show: false
      });
    });

    _defineProperty(_assertThisInitialized(_this), "shutdown", () => {
      const {
        duration
      } = _this.props;

      if (duration > 0) {
        _this.timer = window.setTimeout(() => {
          // eslint-disable-next-line no-underscore-dangle
          _this._hide();

          clearTimeout(_this.timer);
        }, duration);
      }
    });

    return _this;
  }

  var _proto = Toast.prototype;

  _proto.componentDidMount = function componentDidMount() {
    this.shutdown();
  };

  _proto.componentDidUpdate = function componentDidUpdate(prevProps) {
    const {
      show
    } = this.props;

    if (prevProps.show !== show) {
      if (show === true) {
        // eslint-disable-next-line react/no-did-update-set-state
        this.setState({
          show: true
        });
        this.shutdown();
      } else {
        clearTimeout(this.timer);
        this.shutdown();
      }
    }
  };

  _proto.componentWillUnmount = function componentWillUnmount() {
    clearTimeout(this.timer);
  };

  _proto.render = function render() {
    const {
      icon,
      type,
      position,
      duration,
      overlay,
      ...rest
    } = this.props;
    const {
      show
    } = this.state;
    const positionCls = classnames(Toast.baseClass, `${Toast.baseClass}--${position}`, {
      [`${Toast.baseClass}--text`]: type === 'text' || type === 'html',
      [`${Toast.baseClass}--${type}`]: !icon
    });
    return /*#__PURE__*/React.createElement(Popup, _extends({
      position: "center",
      duration: duration,
      overlay: overlay,
      onOpened: this.handleOpened,
      onClose: this.handleColse
    }, rest, {
      className: positionCls,
      show: show
    }), this.renderIcon(), this.renderMessage());
  };

  return Toast;
}(PureComponent);

_defineProperty(Toast, "baseClass", 'r-toast');

_defineProperty(Toast, "defaultOptions", {
  icon: '',
  type: 'text',
  message: '',
  className: '',
  overlay: false,
  onClose: undefined,
  onOpened: undefined,
  duration: 2000,
  // teleport: '#root',
  iconSize: undefined,
  iconPrefix: 'r-icon',
  position: 'center',
  forbidClick: false,
  loadingType: undefined,
  overlayClass: '',
  overlayStyle: undefined,
  closeOnClick: false,
  closeOnClickOverlay: false
});

_defineProperty(Toast, "toastDom", void 0);

_defineProperty(Toast, "toastContainer", void 0);

_defineProperty(Toast, "hideHelper", void 0);

_defineProperty(Toast, "show", options => {
  Toast.unmountNode();

  if (!Toast.toastDom) {
    Toast.toastDom = document.createElement('div');

    if (isToastProps(options)) {
      Toast.toastDom.classList.add('r-toast-contanier');
    }

    if (options.className) {
      Toast.toastDom.classList.add(options.className);
    }

    const teleport = isToastProps(options) && typeof options.teleport === 'string' ? document.querySelector(options.teleport) : options.teleport;
    Toast.toastContainer = teleport ? getMountContanier(teleport) : getMountContanier();
    Toast.toastContainer.appendChild(Toast.toastDom);
  }

  if (Toast.toastDom) {
    const props = Object.assign(Toast.defaultOptions, parseObject(options), {
      show: true
    });

    Toast.hideHelper = () => {
      ReactDOM.render( /*#__PURE__*/React.createElement(Toast, _extends({}, props, {
        show: false
      })), Toast.toastDom);
    }; // eslint-disable-next-line react/no-render-return-value


    return ReactDOM.render( /*#__PURE__*/React.createElement(Toast, props), Toast.toastDom);
  }
});

_defineProperty(Toast, "close", () => {
  if (Toast.toastDom) {
    Toast.hideHelper();
  }

  return null;
});

_defineProperty(Toast, "unmountNode", () => {
  const {
    toastDom,
    toastContainer
  } = Toast;

  if (toastDom) {
    toastContainer.removeChild(toastDom);
    Toast.toastDom = null;
  }
});

export default Toast;
